$NetBSD: patch-ah,v 1.1 2009/01/28 12:47:35 drochner Exp $

--- src/playlist3-messages.c.orig	2009-01-28 14:06:46.000000000 +0100
+++ src/playlist3-messages.c
@@ -29,7 +29,7 @@ void playlist3_message_init(void)
 	{
         GError *error = NULL;
 				gchar *path = gmpc_get_user_path("gmpc.log");
-				message_list = gtk_list_store_new(3, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING);
+				message_list = gtk_list_store_new(3, G_TYPE_INT64, G_TYPE_STRING, G_TYPE_STRING);
 
         log_file = g_io_channel_new_file(path, "a", &error);
         if(error)
@@ -54,10 +54,10 @@ void playlist3_show_error_message(const 
 	gchar *string;
 	playlist3_message_init();
 	gtk_list_store_prepend(message_list, &iter);
-	gtk_list_store_set(message_list, &iter, 0,t, 2, message,-1);
+	gtk_list_store_set(message_list, &iter, 0, (gint64)t, 2, message,-1);
 
 
-	lt = localtime((time_t *)&t);
+	lt = localtime(&t);
 	strftime(text, 64,"%d/%m/%Y-%H:%M:%S", lt);
 
 	string = g_strdup_printf("%s:%s:%s\n",text,error_levels[el], message);
@@ -160,11 +160,11 @@ static void message_cell_data_func(GtkTr
 		gpointer data)
 {
 	time_t t;
-	guint id;
+	gint64 id;
 	gchar text[64];
 	struct tm *lt;
 	gtk_tree_model_get(tree_model, iter, 0,&id, -1);
 	/* gtk_list_store only knows the type unsigned int, not time_T
 	 * so lets do some casting)
 	 */
 	t = (time_t) id;
@@ -160,11 +160,11 @@ static void message_cell_data_func(GtkTr
 	struct tm *lt;
 	gtk_tree_model_get(tree_model, iter, 0,&id, -1);
-	/* gtk_list_store only knows the type unsigned int, not time_T
+	/* gtk_list_store only knows the type int64, not time_T
 	 * so lets do some casting)
 	 */
